Learn R Programming

MVisAGe (version 0.2.1)

tcga.cn.convert: A Function for Reformatting TCGA DNA Copy Number Matrices

Description

This function reformats DNA copy number matrices obtained from the Broad Institute's Firehose GDAC (https://gdac.broadinstitute.org/) so they can be used as input for mVisAGe functions.

Usage

tcga.cn.convert(cn.mat)

Arguments

cn.mat

A matrix of DNA copy number data included in the GISTIC2 output. Typically all_data_by_genes.txt, or a subset thereof, including the Locus.ID and Cytoband columns.

Value

A matrix of DNA copy number data (rows = genes, columns = samples) that is suitable for input to mVisAGe functions.

Examples

Run this code
# NOT RUN {
cn.mat = tcga.cn.convert(cn.mat)

# }

Run the code above in your browser using DataLab